import sys
import os
from pdf2image import convert_from_path

def pdf_to_jpg(pdf_path, output_folder, dpi=300):
    # Ensure output directory exists
    if not os.path.exists(output_folder):
        os.makedirs(output_folder)

    # Convert PDF to images
    images = convert_from_path(pdf_path, dpi=dpi, poppler_path="/usr/bin/")

    # Save images as JPG
    output_files = []
    for i, image in enumerate(images):
        image_path = os.path.join(output_folder, f"page_{i+1}.jpg")
        image.save(image_path, "JPEG")
        output_files.append(image_path)

    # Print the output filenames (for PHP to read)
    print(",".join(output_files))

# Ensure correct number of arguments from PHP
if len(sys.argv) != 3:
    print("Usage: pdf_to_jpg.py <pdf_path> <output_folder>")
    sys.exit(1)

pdf_path = sys.argv[1]
output_folder = sys.argv[2]

# Convert PDF and print results
pdf_to_jpg(pdf_path, output_folder)
